Crate mk_lib

Crate mk_lib 

mk-lib

mk-lib is a library for parsing and running tasks defined in a YAML file.

Data formats

The following data formats are supported:

  • YAML, a self-proclaimed human-friendly configuration language that ain’t markup language.

Re-exports

pub use schema::ActiveTasks;
pub use schema::CompletedTasks;

Modules

cache
Task execution cache helpers
defaults
The defaults module contains the default values for the library
file
The file module contains the file path handling functions
macros
The macros module contains the custom macros used in the library
schema
The schema module contains the data structures used to represent the tasks
secrets
Shared secret vault helpers used by the CLI and task execution
utils
The utils module contains the utility functions used in the library
version
The version module contains the version information for the library

Macros

get_template_command_value
handle_output
run_shell_command

Functions

generate_schema
Generate the JSON Schema for the task configuration file as a pretty-printed JSON string.