Module schema

Module schema 

The schema module contains the data structures used to represent the tasks

Structs

CommandResult
ExecutionInterrupted
IncludeArgs
LocalRun
NpmPackage
PlannedTask
Precondition
This struct represents a precondition that must be met before a task can be executed.
ShellArgs
Shell command with optional flags.
TaskArgs
This struct represents a task that can be executed. A task can contain multiple commands that are executed sequentially. A task can also have preconditions that must be met before the task can be executed.
TaskCache
TaskContext
Used to pass information to tasks This use arc to allow for sharing of data between tasks and allow parallel runs of tasks
TaskDependencyArgs
This struct represents a task dependency. A task can depend on other tasks. If a task depends on another task, the dependent task must be executed before the dependent task.
TaskExecution
TaskPlan
TaskRoot
This struct represents the root of the task schema. It contains all the tasks that can be executed.
UseCargoArgs
UseNpmArgs
ValidationIssue
ValidationReport

Enums

CommandRunner
A single command entry in a task. Can be a shell string or a structured runner object.
ContainerRuntime
The container runtime to use.
ExecutionMode
Include
PlannedCommand
PlannedExecutionMode
Shell
The shell to use. Either a string name (e.g. “bash”) or an object with command and optional args.
Task
A task definition: either a command string shorthand or a full task object.
TaskDependency
A task dependency: either a task name string or an object with a name field.
UseCargo
Enable cargo commands as tasks. Either true or an object with optional settings.
UseNpm
Enable npm scripts as tasks. Either true or an object with optional settings.
ValidationSeverity

Functions

contains_output_reference
extract_output_references
get_output_handler
interpolate_template_string
is_shell_command
is_template_command
resolve_template_command_value
resolve_template_expression
run_task_by_name

Type Aliases

ActiveTasks
CompletedTasks