pub struct LocalRun {
pub command: String,
pub shell: Option<Shell>,
pub test: Option<String>,
pub work_dir: Option<String>,
pub interactive: Option<bool>,
pub ignore_errors: Option<bool>,
pub verbose: Option<bool>,
}Fields
command: StringThe command to run
shell: Option<Shell>The shell to use to run the command
test: Option<String>The test to run before running command If the test fails, the command will not run
work_dir: Option<String>The working directory to run the command in
interactive: Option<bool>Interactive mode If true, the command will be interactive accepting user input
ignore_errors: Option<bool>Ignore errors if the command fails
verbose: Option<bool>Show verbose output
Implementations