pub struct Task {
pub commands: Vec<CommandRunner>,
pub preconditions: Vec<Precondition>,
pub depends_on: Vec<TaskDependency>,
pub labels: HashMap<String, String>,
pub description: String,
pub environment: HashMap<String, String>,
pub env_file: Vec<String>,
}Expand description
This struct represents a task that can be executed. A task can contain multiple commands that are executed sequentially. A task can also have preconditions that must be met before the task can be executed.
Fields
commands: Vec<CommandRunner>preconditions: Vec<Precondition>depends_on: Vec<TaskDependency>labels: HashMap<String, String>description: Stringenvironment: HashMap<String, String>env_file: Vec<String>Implementations