pub struct TaskArgs {Show 21 fields
pub commands: Vec<CommandRunner>,
pub preconditions: Vec<Precondition>,
pub depends_on: Vec<TaskDependency>,
pub labels: HashMap<String, String>,
pub description: String,
pub environment: HashMap<String, String>,
pub env_file: Vec<String>,
pub secrets_path: Vec<String>,
pub secrets: Option<SecretSettings>,
pub vault_location: Option<String>,
pub keys_location: Option<String>,
pub key_name: Option<String>,
pub gpg_key_id: Option<String>,
pub shell: Option<Shell>,
pub parallel: Option<bool>,
pub execution: Option<TaskExecution>,
pub cache: Option<TaskCache>,
pub inputs: Vec<String>,
pub outputs: Vec<String>,
pub ignore_errors: Option<bool>,
pub verbose: Option<bool>,
/* private fields */
}Expand description
This struct represents a task that can be executed. A task can contain multiple commands that are executed sequentially. A task can also have preconditions that must be met before the task can be executed.
Fields
commands: Vec<CommandRunner>The commands to run
preconditions: Vec<Precondition>The preconditions that must be met before the task can be executed
depends_on: Vec<TaskDependency>The tasks that must be executed before this task can be executed
labels: HashMap<String, String>The labels for the task
description: StringThe description of the task
environment: HashMap<String, String>The environment variables to set before running the task
env_file: Vec<String>The environment files to load before running the task
secrets_path: Vec<String>Secret paths to load as dotenv-style environment entries before running the task
secrets: Option<SecretSettings>Canonical task secret settings block.
vault_location: Option<String>The path to the secret vault
keys_location: Option<String>The path to the private keys used for secret decryption
key_name: Option<String>The key name to use for secret decryption
gpg_key_id: Option<String>GPG key ID or fingerprint for hardware/passphrase-protected keys (delegates to system gpg)
shell: Option<Shell>The shell to use when running the task
parallel: Option<bool>Run the commands in parallel It should only work if the task are local_run commands
execution: Option<TaskExecution>Richer execution configuration
cache: Option<TaskCache>Task caching configuration
inputs: Vec<String>Files or glob patterns that affect task output
outputs: Vec<String>Files produced by the task
ignore_errors: Option<bool>Ignore errors if the task fails
verbose: Option<bool>Show verbose output
Implementations