pub struct TaskDependency {
pub name: String,
}Expand description
This struct represents a task dependency. A task can depend on other tasks. If a task depends on another task, the dependent task must be executed before the dependent task.
Fields
name: StringImplementations
Sourceimpl TaskDependency
impl TaskDependency
pub fn run(&self, context: &TaskContext) -> Result<()>