pub struct TaskDependencyArgs {
pub name: String,
}Expand description
This struct represents a task dependency. A task can depend on other tasks. If a task depends on another task, the dependent task must be executed before the dependent task.
Fields
name: StringThe name of the task to depend on
Implementations
Sourceimpl TaskDependencyArgs
impl TaskDependencyArgs
pub fn execute(&self, context: &TaskContext) -> Result<()>