pub struct TaskRoot {Show 15 fields
pub tasks: HashMap<String, Task>,
pub environment: HashMap<String, String>,
pub env_file: Vec<String>,
pub secrets_path: Vec<String>,
pub secrets: Option<SecretSettings>,
pub vault_location: Option<String>,
pub keys_location: Option<String>,
pub key_name: Option<String>,
pub gpg_key_id: Option<String>,
pub use_npm: Option<UseNpm>,
pub use_cargo: Option<UseCargo>,
pub container_runtime: Option<ContainerRuntime>,
pub include: Option<Vec<Include>>,
pub extends: Option<String>,
pub source_path: Option<PathBuf>,
/* private fields */
}Expand description
This struct represents the root of the task schema. It contains all the tasks that can be executed.
Fields
tasks: HashMap<String, Task>The tasks that can be executed
environment: HashMap<String, String>The environment variables to set before running any task
env_file: Vec<String>The environment files to load before running any task
secrets_path: Vec<String>Secret paths to load as dotenv-style environment entries before running any task
secrets: Option<SecretSettings>Canonical secret settings block.
vault_location: Option<String>The path to the secret vault
keys_location: Option<String>The path to the private keys used for secret decryption
key_name: Option<String>The key name to use for secret decryption
gpg_key_id: Option<String>The GPG key ID or fingerprint to use for secret encryption/decryption via the system gpg binary.
When set, mk delegates all vault crypto operations to gpg instead of the built-in PGP engine,
enabling hardware keys (e.g. YubiKey) and passphrase-protected keys.
use_npm: Option<UseNpm>This allows mk to use npm scripts as tasks
use_cargo: Option<UseCargo>This allows mk to use cargo commands as tasks
container_runtime: Option<ContainerRuntime>Default container runtime to use for container commands
include: Option<Vec<Include>>Includes additional files to be merged into the current file
extends: Option<String>Extend another root task file
source_path: Option<PathBuf>Absolute path to the config file used to load this root
Implementations
Sourceimpl TaskRoot
impl TaskRoot
pub fn from_file(file: impl AsRef<Path>) -> Result<Self>
pub fn from_hashmap(tasks: HashMap<String, Task>) -> Self
pub fn config_base_dir(&self) -> PathBuf
pub fn cache_base_dir(&self) -> PathBuf
pub fn resolve_from_config(&self, value: &str) -> PathBuf
pub fn normalized_secret_settings(&self) -> Option<SecretSettings>