The schema module contains the data structures used to represent the tasks
Structs
- Command
Result - Execution
Interrupted - Include
Args - Local
Run - NpmPackage
- Planned
Task - Precondition
- This struct represents a precondition that must be met before a task can be executed.
- Shell
Args - Shell command with optional flags.
- Task
Args - This struct represents a task that can be executed. A task can contain multiple commands that are executed sequentially. A task can also have preconditions that must be met before the task can be executed.
- Task
Cache - Task
Context - Used to pass information to tasks This use arc to allow for sharing of data between tasks and allow parallel runs of tasks
- Task
Dependency Args - This struct represents a task dependency. A task can depend on other tasks. If a task depends on another task, the dependent task must be executed before the dependent task.
- Task
Execution - Task
Plan - Task
Root - This struct represents the root of the task schema. It contains all the tasks that can be executed.
- UseCargo
Args - UseNpm
Args - Validation
Issue - Validation
Report
Enums
- Command
Runner - A single command entry in a task. Can be a shell string or a structured runner object.
- Container
Runtime - The container runtime to use.
- Execution
Mode - Include
- Planned
Command - Planned
Execution Mode - Shell
- The shell to use. Either a string name (e.g. “bash”) or an object with
commandand optionalargs. - Task
- A task definition: either a command string shorthand or a full task object.
- Task
Dependency - A task dependency: either a task name string or an object with a
namefield. - UseCargo
- Enable cargo commands as tasks. Either
trueor an object with optional settings. - UseNpm
- Enable npm scripts as tasks. Either
trueor an object with optional settings. - Validation
Severity
Functions
- contains_
output_ reference - extract_
output_ references - get_
output_ handler - interpolate_
template_ string - is_
shell_ command - is_
template_ command - resolve_
template_ command_ value - resolve_
template_ expression - run_
task_ by_ name