Module schema

Module schema 

The schema module contains the data structures used to represent the tasks

Structs

CommandResult
IncludeArgs
LocalRun
NpmPackage
PlannedTask
Precondition
This struct represents a precondition that must be met before a task can be executed.
ShellArgs
TaskArgs
This struct represents a task that can be executed. A task can contain multiple commands that are executed sequentially. A task can also have preconditions that must be met before the task can be executed.
TaskCache
TaskContext
Used to pass information to tasks This use arc to allow for sharing of data between tasks and allow parallel runs of tasks
TaskDependencyArgs
This struct represents a task dependency. A task can depend on other tasks. If a task depends on another task, the dependent task must be executed before the dependent task.
TaskExecution
TaskPlan
TaskRoot
This struct represents the root of the task schema. It contains all the tasks that can be executed.
UseCargoArgs
UseNpmArgs
ValidationIssue
ValidationReport

Enums

CommandRunner
ContainerRuntime
ExecutionMode
Include
PlannedCommand
PlannedExecutionMode
Shell
Task
TaskDependency
UseCargo
UseNpm
ValidationSeverity

Functions

contains_output_reference
extract_output_references
get_output_handler
interpolate_template_string
is_shell_command
is_template_command
resolve_template_command_value
resolve_template_expression
run_task_by_name

Type Aliases

ActiveTasks
CompletedTasks