The schema module contains the data structures used to represent the tasks
Structs
- This struct represents a precondition that must be met before a task can be executed.
- This struct represents a task that can be executed. A task can contain multiple commands that are executed sequentially. A task can also have preconditions that must be met before the task can be executed.
- This struct represents a task dependency. A task can depend on other tasks. If a task depends on another task, the dependent task must be executed before the dependent task.
- This struct represents the root of the task schema. It contains all the tasks that can be executed.