pub struct TaskContext {Show 18 fields
pub task_root: Arc<TaskRoot>,
pub active_tasks: ActiveTasks,
pub completed_tasks: CompletedTasks,
pub multi: Arc<MultiProgress>,
pub env_vars: HashMap<String, String>,
pub task_outputs: Arc<Mutex<HashMap<String, String>>>,
pub secret_vault_location: Option<String>,
pub secret_keys_location: Option<String>,
pub secret_key_name: Option<String>,
pub shell: Option<Arc<Shell>>,
pub container_runtime: Option<ContainerRuntime>,
pub ignore_errors: Option<bool>,
pub verbose: Option<bool>,
pub force: bool,
pub json_events: bool,
pub is_nested: bool,
pub cache_store: Arc<Mutex<CacheStore>>,
pub current_task_name: Option<String>,
}Expand description
Used to pass information to tasks This use arc to allow for sharing of data between tasks and allow parallel runs of tasks
Fields
task_root: Arc<TaskRoot>active_tasks: ActiveTaskscompleted_tasks: CompletedTasksmulti: Arc<MultiProgress>env_vars: HashMap<String, String>task_outputs: Arc<Mutex<HashMap<String, String>>>secret_vault_location: Option<String>secret_keys_location: Option<String>secret_key_name: Option<String>shell: Option<Arc<Shell>>container_runtime: Option<ContainerRuntime>ignore_errors: Option<bool>verbose: Option<bool>force: booljson_events: boolis_nested: boolcache_store: Arc<Mutex<CacheStore>>current_task_name: Option<String>Implementations
Sourceimpl TaskContext
impl TaskContext
pub fn empty() -> Self
pub fn empty_with_root(task_root: Arc<TaskRoot>) -> Self
pub fn new(task_root: Arc<TaskRoot>) -> Self
pub fn new_with_options( task_root: Arc<TaskRoot>, force: bool, json_events: bool, ) -> Self
pub fn from_context(context: &TaskContext) -> Self
pub fn from_context_with_args( context: &TaskContext, ignore_errors: bool, verbose: bool, ) -> Self
pub fn extend_env_vars<I>(&mut self, iter: I)
pub fn set_shell(&mut self, shell: &Shell)
pub fn set_secret_vault_location(&mut self, vault_location: impl Into<String>)
pub fn set_secret_keys_location(&mut self, keys_location: impl Into<String>)
pub fn set_secret_key_name(&mut self, key_name: impl Into<String>)
pub fn set_container_runtime(&mut self, runtime: &ContainerRuntime)
pub fn set_ignore_errors(&mut self, ignore_errors: bool)
pub fn set_verbose(&mut self, verbose: bool)
pub fn insert_task_output( &self, name: impl Into<String>, value: impl Into<String>, ) -> Result<()>
pub fn get_task_output(&self, name: &str) -> Result<Option<String>>
pub fn has_task_output(&self, name: &str) -> Result<bool>
pub fn shell(&self) -> Arc<Shell>
pub fn ignore_errors(&self) -> bool
pub fn verbose(&self) -> bool
pub fn is_task_active(&self, task_name: &str) -> Result<bool>
pub fn is_task_completed(&self, task_name: &str) -> Result<bool>
pub fn mark_task_active(&self, task_name: &str) -> Result<()>
pub fn unmark_task_active(&self, task_name: &str) -> Result<()>
pub fn mark_task_complete(&self, task_name: &str) -> Result<()>
pub fn emit_event<T: Serialize>(&self, value: &T) -> Result<()>
pub fn set_current_task_name(&mut self, task_name: &str)
pub fn resolve_from_config(&self, value: &str) -> PathBuf