pub struct TaskRoot {Show 13 fields
pub tasks: HashMap<String, Task>,
pub environment: HashMap<String, String>,
pub env_file: Vec<String>,
pub secrets_path: Vec<String>,
pub vault_location: Option<String>,
pub keys_location: Option<String>,
pub key_name: Option<String>,
pub use_npm: Option<UseNpm>,
pub use_cargo: Option<UseCargo>,
pub container_runtime: Option<ContainerRuntime>,
pub include: Option<Vec<Include>>,
pub extends: Option<String>,
pub source_path: Option<PathBuf>,
}Expand description
This struct represents the root of the task schema. It contains all the tasks that can be executed.
Fields
tasks: HashMap<String, Task>The tasks that can be executed
environment: HashMap<String, String>The environment variables to set before running any task
env_file: Vec<String>The environment files to load before running any task
secrets_path: Vec<String>Secret paths to load as dotenv-style environment entries before running any task
vault_location: Option<String>The path to the secret vault
keys_location: Option<String>The path to the private keys used for secret decryption
key_name: Option<String>The key name to use for secret decryption
use_npm: Option<UseNpm>This allows mk to use npm scripts as tasks
use_cargo: Option<UseCargo>This allows mk to use cargo commands as tasks
container_runtime: Option<ContainerRuntime>Default container runtime to use for container commands
include: Option<Vec<Include>>Includes additional files to be merged into the current file
extends: Option<String>Extend another root task file
source_path: Option<PathBuf>Absolute path to the config file used to load this root
Implementations