pub struct TaskRoot {
pub tasks: HashMap<String, Task>,
}Expand description
This struct represents the root of the task schema. It contains all the tasks that can be executed.
Fields
tasks: HashMap<String, Task>Implementations